
Tools for turning [Snowflake](https://www.snowflake.com/) into a Snow Day. ❄️

A little bit of sass with a whole lot of `@dataclass`.


![Snowday](snowday.png)


### Installation


```
pip install snowday
```


### What does it do?

#### Connector

![Snowday Connector 1](readme_gif/conn1.gif)

![Snowday Connector 2](readme_gif/conn2.gif)


#### Objects

![Snowday Objects 1](readme_gif/obj1.gif)

![Snowday Objects 2](readme_gif/obj2.gif)


#### All together now

![Snowday All Together](readme_gif/alltogether.gif)


### License


Snowday is licensed under GPLv3.0.
